simsopt.util package
====================

Submodules
----------

simsopt.util.constants module
-----------------------------

.. automodule:: simsopt.util.constants
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.famus\_helpers module
----------------------------------

.. automodule:: simsopt.util.famus_helpers
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.fourier\_interpolation module
------------------------------------------

.. automodule:: simsopt.util.fourier_interpolation
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.logger module
--------------------------

.. automodule:: simsopt.util.logger
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.mpi module
-----------------------

.. automodule:: simsopt.util.mpi
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.mpi\_logger module
-------------------------------

.. automodule:: simsopt.util.mpi_logger
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.permanent\_magnet\_helper\_functions module
--------------------------------------------------------

.. automodule:: simsopt.util.permanent_magnet_helper_functions
   :members:
   :undoc-members:
   :show-inheritance:

simsopt.util.polarization\_project module
-----------------------------------------

.. automodule:: simsopt.util.polarization_project
   :members:
   :undoc-members:
   :show-inheritance:

